function display_results(s, p, b, loopInd, h)
% display_results(s, p, b, loopInd, h)
% displays an approximation p obtained from applying the GLM to a signal 
% time-series s. In the case of voxel 2 (loopInd = 2), the signal and
% its approximation are shown superimposed in a separate figure window
% and the beta values are listed in the figure title. Two bar plots show
% the beta values for the constant predictor (green bars on left subplot) 
% and the beta values for sentences (red) and nonwords (blue) are shown
% in the right subplot

figure(h)
subplot(1,2,1)
hold on
bar(loopInd,b(1),'facecolor',[0 0.4 0]);

figure(h)
subplot(1,2,2)
hold on
bar(loopInd-0.15,b(2),'facecolor','r','barwidth',0.2);
bar(loopInd+0.15,b(3),'facecolor','b','barwidth',0.2);

if loopInd==2
    figure('units','normalized','position',[0 0 1 0.5]);
    hold on
    plot(s,'-k','linewidth',2.5);
    plot(p,'-','color',[1 0 1],'linewidth',3.5);
    b = round(100*b)/100;
    title({'Voxel 2:';['\beta_1=',num2str(b(1)),', \beta_2=',num2str(b(2)),', \beta_3=',num2str(b(3))]},...
        'fontsize',18,'fontweight','bold');
    legend({'True signal','Approximation'},'fontsize',16,'location','southeast','box','off');
    xlabel('Time','fontsize',18);
    ylabel('Signal intensity','fontsize',18);
    set(gca,'xlim', [0, (1.1*numel(s))], 'fontsize',16);
    box off
end

if loopInd == 6
    figure(h)
    subplot(1,2,1)
    title('\beta for the constant predictor','fontsize',18,'fontweight','bold');
    set(gca,'xlim',[0 7],'xtick',1:6,'fontsize',16);
    ylabel('\beta weight','fontsize',18);
    xlabel('voxel','fontsize',18);
    box off

    figure(h)
    subplot(1,2,2)
    title({'\beta for the sentence (red)';'and nonword (blue) predictor'},'fontsize',18,'fontweight','bold');
    set(gca,'xlim',[0 7],'xtick',1:6,'fontsize',16);
    ylabel('\beta weight','fontsize',18);
    xlabel('voxel','fontsize',18);
    box off   
end