function display_signal(signal)
% display_signal(signal)
% displays a signal time-series from a single voxel of fMRI data, given
% known information about the start times and duration for presentation
% of sentences and nonwords in the language experiment. red and blue bars
% indicate time blocks for sentences and nonwords, respectively
    
sentenceBlockStartTimes = [9 36 63 81 99 117 153 162];
nonwordBlockStartTimes = [18 27 54 72 108 126 144 171];
blockDurationTR = 9;

figure('units','normalized','position',[0 0 1 0.5]);
hold on
    
yMax = max(signal);
if yMax > 0
    yMax = 1.01*yMax;
else
    yMax = 0.99*yMax;
end
yMin = min(signal);
if -yMin > 0 
    yMin = 1.11*yMin;
else
    yMin = 0.99*yMin;
end
    
for s = 1:length(sentenceBlockStartTimes)
    x = [sentenceBlockStartTimes(s), ...
         sentenceBlockStartTimes(s)+blockDurationTR-1, ...
         sentenceBlockStartTimes(s)+blockDurationTR-1, ...
         sentenceBlockStartTimes(s), ...
         sentenceBlockStartTimes(s)];
    y = [yMin, yMin, yMax, yMax, yMin];
    fill(x,y,'r','facecolor','r','facealpha',0.2,'linestyle','none');
end
    
for n = 1:length(nonwordBlockStartTimes)
    x = [nonwordBlockStartTimes(n), ...
         nonwordBlockStartTimes(n)+blockDurationTR-1, ...
         nonwordBlockStartTimes(n)+blockDurationTR-1, ...
         nonwordBlockStartTimes(n), ...
         nonwordBlockStartTimes(n)];
    y = [yMin, yMin, yMax, yMax, yMin];
    fill(x,y,'b','facecolor','b','facealpha',0.2,'linestyle','none');
end
    
y1 = yMin+0.95*(yMax-yMin);
y2 = yMin+0.89*(yMax-yMin);
fill([186 189 189 186 186], [y2 y2 y1 y1 y2], 'r','facecolor','r','facealpha',0.2,'linestyle','none');
text(191, (y1+y2)/2, 'Sentences', 'fontsize',16,'verticalalignment','middle','horizontalalignment','left');
    
y1 = yMin+0.83*(yMax-yMin);
y2 = yMin+0.77*(yMax-yMin);
fill([186 189 189 186 186], [y2 y2 y1 y1 y2], 'b','facecolor','b','facealpha',0.2,'linestyle','none');
text(191, (y1+y2)/2, 'Nonwords', 'fontsize',16,'verticalalignment','middle','horizontalalignment','left');
    
plot(signal,'.-k','linewidth',1);
xlabel('time','fontsize',16,'fontweight','bold')
ylabel('signal intensity', 'fontsize', 16, 'fontweight', 'bold');
set(gca,'ylim',[yMin,yMax],'xlim',[1 size(signal,2)+35], 'fontsize', 16);
box off
    
end